@@ -103,7 +103,7 @@ rdsampsi = function(data = NULL,
                     covs = NULL,
                     deriv = 0,
                     p = 1,
-                    q = 2,
+                    q = NULL,
                     h = NULL,
                     b = NULL,
                     rho = NULL,
@@ -191,6 +191,9 @@ rdsampsi = function(data = NULL,
     }
   }
 
+  if (is.null(q)){ q = p + 1}
+
+
   #################################################################
   # Bias and variance
   #################################################################
